@@ -2,14 +2,11 @@ package WWW::GoKGS::Scraper::TournGames;
 use strict;
 use warnings FATAL => 'all';
 use parent qw/WWW::GoKGS::Scraper/;
-use URI;
 use Web::Scraper;
 use WWW::GoKGS::Scraper::Filters qw/datetime/;
 use WWW::GoKGS::Scraper::TournLinks qw/process_links/;
 
-sub _build_base_uri {
-    URI->new('http://www.gokgs.com/tournGames.jsp');
-}
+sub base_uri { 'http://www.gokgs.com/tournGames.jsp' }
 
 sub _build_scraper {
     my $self = shift;
@@ -38,14 +35,13 @@ sub _build_scraper {
         };
     };
 
-
     my $game = scraper {
         process '//td[1]/a', 'sgf_uri' => '@href';
         process '//td[2]', 'white' => [ 'TEXT', $player ];
         process '//td[3]', 'black' => [ 'TEXT', $player ];
         process '//td[3]', 'maybe_bye' => 'TEXT';
         process '//td[4]', 'setup' => 'TEXT';
-        process '//td[5]', 'start_time' => [ 'TEXT', $self->get_filter('games[].start_time') ];
+        process '//td[5]', 'start_time' => [ 'TEXT', \&datetime ];
         process '//td[6]', 'result' => [ 'TEXT', $result ];
     };
 
@@ -56,26 +52,10 @@ sub _build_scraper {
                 'games[]' => $game;
         process '//a[text()="Previous round"]', 'previous_round_uri' => '@href';
         process '//a[text()="Next round"]', 'next_round_uri' => '@href';
-        process_links $self->_assoc_filter('links.rounds[].start_time'),
-                      $self->_assoc_filter('links.rounds[].end_time');
+        process_links;
     };
 }
 
-sub _build_filter {
-    my $self = shift;
-
-    {
-        'games[].start_time' => [ \&datetime ],
-        'links.rounds[].start_time' => [ \&datetime ],
-        'links.rounds[].end_time'   => [ \&datetime ],
-    };
-}
-
-sub _assoc_filter {
-    my ( $self, $key ) = @_;
-    ( $key, [ $self->get_filter($key) ] );
-}
-
 sub scrape {
     my ( $self, @args ) = @_;
     my $result = $self->SUPER::scrape( @args );
@@ -185,14 +165,28 @@ WWW::GoKGS::Scraper::TournGames - Games of the KGS tournament
 
 This class inherits from L<WWW::GoKGS::Scraper>.
 
-=head2 ATTRIBUTES
+=head2 CLASS METHODS
 
 =over 4
 
-=item $URI = $tuorn_games->base_uri
+=item $uri = $class->base_uri
 
-Defaults to C<http://www.gokgs.com/tournGames.jsp>.
-This attribute is read-only.
+  # => "http://www.gokgs.com/tournGames.jsp"
+
+=item $URI = $class->build_uri( $k1 => $v1, $k2 => $v2, ... )
+
+=item $URI = $class->build_uri({ $k1 => $v1, $k2 => $v2, ... })
+
+=item $URI = $class->build_uri([ $k1 => $v1, $k2 => $v2, ... ])
+
+Given key-value pairs of query parameters, constructs a L<URI> object
+which consists of C<base_uri> and the paramters.
+
+=back
+
+=head2 INSTANCE METHODS
+
+=over 4
 
 =item $UserAgent = $tourn_games->user_agent
 
@@ -202,32 +196,6 @@ Can be used to get or set an L<LWP::UserAgent> object which is used to
 C<GET> the requested resource. Defaults to the C<LWP::UserAgent> object
 shared by L<Web::Scraper> users (C<$Web::Scraper::UserAgent>).
 
-=back
-
-=head2 METHODS
-
-=over 4
-
-=item $tourn_games->add_filter( 'games[].start_time' => $filter )
-
-=item $tourn_games->add_filter( 'links.rounds[].start_time' => $filter )
-
-=item $tourn_games->add_filter( 'links.rounds[].end_time' => $filter )
-
-Adds a game start time or a round start/end time filter.
-C<$filter> is called with a date string
-such as C<2014-05-17T19:05Z>. C<$filter> can be either a filter class name
-or a subref. See L<Web::Scraper::Filter> for details.
-
-  use Time::Piece qw/gmtime/;
-
-  $tourn_games->add_filter(
-      'games[].start_time' => sub {
-          my $start_time = shift; # => "2014-05-17T19:05Z"
-          gmtime->strptime( $start_time, '%Y-%m-%dT%H:%MZ' );
-      }
-  );
-
 =item $HashRef = $tourn_games->scrape( URI->new(...) )
 
 =item $HashRef = $tourn_games->scrape( HTTP::Response->new(...) )
