@@ -2,14 +2,10 @@ package WWW::GoKGS::Scraper::TournInfo;
 use strict;
 use warnings FATAL => 'all';
 use parent qw/WWW::GoKGS::Scraper/;
-use URI;
 use Web::Scraper;
-use WWW::GoKGS::Scraper::Filters qw/datetime/;
 use WWW::GoKGS::Scraper::TournLinks qw/process_links/;
 
-sub _build_base_uri {
-    URI->new('http://www.gokgs.com/tournInfo.jsp');
-}
+sub base_uri { 'http://www.gokgs.com/tournInfo.jsp' }
 
 sub _build_scraper {
     my $self = shift;
@@ -18,34 +14,17 @@ sub _build_scraper {
         process '//h1', 'name' => [ 'TEXT', sub { s/ \([^)]+\)$// } ];
         process '//node()[preceding-sibling::h1 and following-sibling::div]',
                 'description[]' => sub { $_[0]->as_XML };
-        process_links $self->_assoc_filter('links.rounds[].start_time'),
-                      $self->_assoc_filter('links.rounds[].end_time');
+        process_links;
     };
 }
 
-sub _build_filter {
-    my $self = shift;
-
-    {
-        'links.rounds[].start_time' => [ \&datetime ],
-        'links.rounds[].end_time'   => [ \&datetime ],
-    };
-}
-
-sub _assoc_filter {
-    my ( $self, $key ) = @_;
-    ( $key, [ $self->get_filter($key) ] );
-}
-
 sub scrape {
     my ( $self, @args ) = @_;
     my $result = $self->SUPER::scrape( @args );
 
-    return $result unless $result->{description};
-
-    $result->{description} = $self->run_filter('description', do {
-        join q{}, @{$result->{description}};
-    });
+    if ( exists $result->{description} ) {
+        $result->{description} = join q{}, @{$result->{description}};
+    }
 
     $result;
 }
@@ -97,14 +76,28 @@ WWW::GoKGS::Scraper::TournInfo - Information for the KGS tournament
 
 This class inherits from L<WWW::GoKGS::Scraper>.
 
-=head2 ATTRIBUTES
+=head2 CLASS METHODS
 
 =over 4
 
-=item $URI = $tourn_info->base_uri
+=item $uri = $class->base_uri
 
-Defaults to C<http://www.gokgs.com/tournInfo.jsp>.
-This attribute is read-only.
+  # => "http://www.gokgs.com/tournInfo.jsp"
+
+=item $URI = $class->build_uri( $k1 => $v1, $k2 => $v2, ... )
+
+=item $URI = $class->build_uri({ $k1 => $v1, $k2 => $v2, ... })
+
+=item $URI = $class->build_uri([ $k1 => $v1, $k2 => $v2, ... ])
+
+Given key-value pairs of query parameters, constructs a L<URI> object
+which consists of C<base_uri> and the paramters.
+
+=back
+
+=head2 INSTANCE METHODS
+
+=over 4
 
 =item $UserAgent = $tourn_info->user_agent
 
@@ -114,43 +107,6 @@ Can be used to get or set an L<LWP::UserAgent> object which is used to
 C<GET> the requested resource. Defaults to the C<LWP::UserAgent> object
 shared by L<Web::Scraper> users (C<$Web::Scraper::UserAgent>).
 
-=back
-
-=head2 METHODS
-
-=over 4
-
-=item $tourn_info->add_filter( 'description' => $filter )
-
-Adds a tournament description filter. C<$filter> is called with
-an HTML string. C<$filter> can be either a filter class name
-or a subref. See L<Web::Scraper::Filter> for details.
-
-  $tourn_info->add_filter(
-      'description' => sub { 
-          my $html = shift;
-          $html =~ s/<.*?>//g; # strip HTML tags
-          $html;
-      }
-  );
-
-=item $tourn_info->add_filter( 'links.rounds[].start_time' => $filter )
-
-=item $tourn_info->add_filter( 'links.rounds[].end_time' => $filter )
-
-Adds a round start/end time filter. C<$filter> is called with a date string
-such as C<2014-05-17T19:05Z>. C<$filter> can be either a filter class name
-or a subref. See L<Web::Scraper::Filter> for details.
-
-  use Time::Piece qw/gmtime/;
-
-  $tourn_info->add_filter(
-      'links.rounds[].start_time' => sub {
-          my $start_time = shift; # => "2014-05-17T19:05Z"
-          gmtime->strptime( $start_time, '%Y-%m-%dT%H:%MZ' );
-      }
-  );
-
 =item $HashRef = $tourn_info->scrape( URI->new(...) )
 
 =item $HashRef = $tourn_info->scrape( HTTP::Response->new(...) )
